# - Check for the presence of pthread
#
# The following variables are set when pthread is found:
#  HAVE_pthread       = Set to true, if all components of pthread
#                          have been found.
#  pthread_INCLUDE_DIR   = Include path for the header files of pthread
#  pthread_LIBRARIES  = Link these to use pthread

## -----------------------------------------------------------------------------
## Check for the header files

find_path (pthread_INCLUDE_DIR pthread.h
  PATHS ${pthread_INC} /usr/local/include /usr/include /sw/include /opt/local/include
  PATH_SUFFIXES <optional path extension>
  )

## -----------------------------------------------------------------------------
## Check for the library

find_library (pthread_LIBRARIES libpthread.so
  PATHS ${pthread_LIB} /usr/local/lib /usr/lib /lib /sw/lib /opt/local/lib
  )

## -----------------------------------------------------------------------------
## Actions taken when all components have been found

if (pthread_INCLUDE_DIR AND pthread_LIBRARIES)
  set (HAVE_pthread TRUE)
else (pthread_INCLUDE_DIR AND pthread_LIBRARIES)
  if (NOT pthread_FIND_QUIETLY)
    if (NOT pthread_INCLUDE_DIR)
      message (STATUS "Unable to find pthread header files!")
    endif (NOT pthread_INCLUDE_DIR)
    if (NOT pthread_LIBRARIES)
      message (STATUS "Unable to find pthread library files!")
    endif (NOT pthread_LIBRARIES)
  endif (NOT pthread_FIND_QUIETLY)
endif (pthread_INCLUDE_DIR AND pthread_LIBRARIES)

if (HAVE_pthread)
  if (NOT pthread_FIND_QUIETLY)
    message (STATUS "Found components for pthread")
    message (STATUS "pthread_INCLUDE_DIR = ${pthread_INCLUDE_DIR}")
    message (STATUS "pthread_LIBRARIES = ${pthread_LIBRARIES}")
  endif (NOT pthread_FIND_QUIETLY)
else (HAVE_pthread)
  if (pthread_FIND_REQUIRED)
    SET(pthread_LIB "" CACHE PATH "Paths where to additionally look for
    libs")
    SET(pthread_INC "" CACHE PATH "Paths where to additionally look for
    includes")
    message (FATAL_ERROR "Could not find pthread!")
  endif (pthread_FIND_REQUIRED)
endif (HAVE_pthread)

mark_as_advanced (
  HAVE_pthread
  pthread_LIBRARIES
  pthread_INCLUDE_DIR
  )
